@@ -7,7 +7,7 @@ use File::Find;
 use File::Copy;
 
 our @ISA = qw(Exporter);
-our $VERSION = '0.0.10';
+our $VERSION = '0.0.11';
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -129,7 +129,7 @@ sub tar {
 	my( $self, $ts, $hasExcludeTag ) = @_;
 	my $filename = sprintf("%s/%s_%s.tar.gz",$self->{targetDir},$self->{prefix},$ts);
         #create a temp output file in case something goes wrong. Replace the temp with the target only at the end
-        my $tmpFileName = "temp.tar.gz"; 
+        my $tmpFileName = sprintf("%s/temp.tar.gz",$self->{targetDir});
 	my $option = '';
 	$option = '--exclude-tag-all=NOTAR' if $hasExcludeTag;
 	my $output = `tar cvzf $tmpFileName $option $self->{sourceDir} 2>&1 1>/dev/null`;
@@ -145,7 +145,7 @@ sub perlTar {
 	my( $self, $ts ) = @_;
 	my $filename = sprintf("%s/%s_%s.tar.gz",$self->{targetDir},$self->{prefix},$ts);
         #create a temp output file in case something goes wrong. Replace the temp with the target only at the end
-        my $tmpFileName = "temp.tar.gz"; 
+        my $tmpFileName = sprintf("%s/temp.tar.gz",$self->{targetDir});
 	my $tar = new Archive::Tar;
 	our @files=();
 	find(sub {push(@files,$File::Find::name);},$self->{sourceDir});
